==> jeppetto-dao-0.7.2-sources.jar: org/iternine/jeppetto/dao/Projection.java <==
/*
 * Copyright (c) 2011 Jeppetto and Jonathan Thompson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.iternine.jeppetto.dao;


public class Projection {

    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private String field;
    private Object details;


    //-------------------------------------------------------------
    // Constructors
    //-------------------------------------------------------------

    public Projection() {
    }


    public Projection(String field, Object details) {
        this.field = field;
        this.details = details;
    }


    //-------------------------------------------------------------
    // Methods - Getter/Setter
    //-------------------------------------------------------------

    public String getField() {
        return field;
    }


    public void setField(String field) {
        this.field = field;
    }


    public Object getDetails() {
        return details;
    }


    public void setDetails(Object details) {
        this.details = details;
    }
}

==> jeppetto-dao-0.9-rc1-sources.jar: org/iternine/jeppetto/dao/Projection.java <==
/*
 * Copyright (c) 2011-2014 Jeppetto and Jonathan Thompson
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.iternine.jeppetto.dao;


public class Projection {

    //-------------------------------------------------------------
    // Variables - Private
    //-------------------------------------------------------------

    private String field;
    private Object details;


    //-------------------------------------------------------------
    // Constructors
    //-------------------------------------------------------------

    public Projection() {
    }


    public Projection(String field, Object details) {
        this.field = field;
        this.details = details;
    }


    //-------------------------------------------------------------
    // Methods - Getter/Setter
    //-------------------------------------------------------------

    public String getField() {
        return field;
    }


    public void setField(String field) {
        this.field = field;
    }


    public Object getDetails() {
        return details;
    }


    public void setDetails(Object details) {
        this.details = details;
    }


    //-------------------------------------------------------------
    // Methods - Object
    //-------------------------------------------------------------

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }

        if (o == null || getClass() != o.getClass()) {
            return false;
        }

        Projection projection = (Projection) o;

        return !(details != null ? !details.equals(projection.details) : projection.details != null)
               && !(field != null ? !field.equals(projection.field) : projection.field != null);

    }


    @Override
    public int hashCode() {
        int result = field != null ? field.hashCode() : 0;

        result = 31 * result + (details != null ? details.hashCode() : 0);

        return result;
    }


    @Override
    public String toString() {
        final StringBuilder sb = new StringBuilder();

        sb.append("Projection");
        sb.append("{ field='").append(field).append('\'');
        sb.append(", details=").append(details);
        sb.append(" }");

        return sb.toString();
    }
}
